@@ -1,8 +1,14 @@
 gofm <-
 function(output) 
 {
-    LL0 <- output$loglik[1]
-    LLb <- output$loglik[2]
+    if (any(class(output) == "clogit") == TRUE) {
+        LL0 <- output$loglik[1]
+        LLb <- output$loglik[2]
+    } else if (any(class(output) == "glm") == TRUE) {
+        LL0 <- -1 * nrow(output$data) * log(2)
+        LLb <- as.vector(logLik(output))
+    }
+
     K <- length(output$coefficients)
     rho2 <- 1 - (LLb / LL0)
     rho2a <- 1 - ((LLb - K) / LL0)
